@@ -8,16 +8,12 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecr._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cdk_fargate_run_task._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-kaniko", "0.2.50", __name__[0:-6], "cdk-kaniko@0.2.50.jsii.tgz"
+    "cdk-kaniko", "2.0.2", __name__[0:-6], "cdk-kaniko@2.0.2.jsii.tgz"
 )
 
 __all__ = [
